@@ -21,7 +21,7 @@ use Getopt::Long qw{ :config posix_default gnu_compat bundling };
 use base 'Exporter';
 our @EXPORT_OK = qw/startup/;
 
-our $VERSION = '0.16'; # Don't forget to update the manpage version, too!
+our $VERSION = '0.17'; # Don't forget to update the manpage version, too!
 
 # Simple command-line processing with transparent
 # support for config files.
@@ -188,13 +188,28 @@ sub die                         ## no critic ( Subroutines::RequireFinalReturn )
 
 # Die with a usage summary.
 sub die_usage
+{
+    my $self = shift;
+    my $msg  = shift;
+
+    print {\*STDERR} $self->_usage_message($msg);
+    exit 1;
+}
+
+# Return a usage message
+sub _usage_message
 {
     my $self    = shift;
+    my $msg     = shift;
     my $optspec = $self->get_optspec;
+    my $name    = basename($PROGRAM_NAME);
+
+    # The message to be returned
+    my $message = '';
 
     # This happens if options aren't defined in the constructor
     # and then die_usage() is called directly or indirectly.
-    $self->die('die_usage() called without defining any options')
+    $self->die('_usage_message() called without defining any options')
         unless keys %{$optspec};
 
     # In the usage text, show the option names, not the aliases.
@@ -206,9 +221,16 @@ sub die_usage
     # Note the length of the longest option
     my $length  = max map { length() } keys %options;
 
+    # Print the requested message, if any
+    if (defined $msg)
+    {
+        ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
+        $message .= sprintf '%s: FATAL: %s\n', $name, $msg;
+    }
+
     # Now print the help message.
-    print 'usage: ' . basename($PROGRAM_NAME) . ' ' . $self->get_usage . "\n";
-    print "Options:\n";
+    $message .= 'usage: ' . basename($PROGRAM_NAME) . ' ' . $self->get_usage . "\n";
+    $message .= "Options:\n";
 
     # Print the options, sorted in dictionary order.
     for my $option (sort keys %options)
@@ -218,7 +240,7 @@ sub die_usage
         my $spec   = $options{$option};
 
         # Print the basic help option
-        printf "    %-${length}s - %s\n", $option, $spec->{desc};
+        $message .= sprintf "    %-${length}s - %s\n", $option, $spec->{desc};
 
         # Print aliases, if any
         if (@{ $spec->{names} } > 1)
@@ -226,17 +248,17 @@ sub die_usage
             my @aliases = @{ $spec->{names} };
             shift @aliases;
 
-            printf "%${indent}s Aliases: %s\n", '', join(', ', @aliases);
+            $message .= sprintf "%${indent}s Aliases: %s\n", '', join(', ', @aliases);
         }
 
         # Print negation, if any
         if ($spec->{bool})
         {
-            printf "%${indent}s Negate this with --no-%s\n", '', $option;
+            $message .= sprintf "%${indent}s Negate this with --no-%s\n", '', $option;
         }
     }
 
-    exit 1;
+    return $message;
 }
 
 # Returns the "default" optspec, consisting of options
@@ -469,7 +491,16 @@ sub _process_command_line
 
     # Parse the command line and die if anything is wrong.
     my $opts_ok = GetOptions( \%options, keys %{$optspec} );
-    $self->die_usage if $options{help} || !$opts_ok ;
+
+    if ($options{help})
+    {
+        print $self->_usage_message();
+        exit 0;
+    }
+    elsif ( !$opts_ok )
+    {
+        $self->die_usage();
+    }
 
     # Treat array and hash options as CSV records, so we can
     # cope with quoting and values containing commas.
@@ -484,7 +515,10 @@ sub _process_command_line
             for my $value (@{$options{$option}})
             {
                 $csv->parse($value)
-                    or $self->die("Can't parse --$option option: $value");
+                    or $self->die_usage(
+                        "Can't parse --$option option \"$value\": "
+                        . $csv->error_diag()
+                    );
                 push @values, $csv->fields;
             }
 
@@ -704,9 +738,10 @@ sub print_manpage
     my $self   = shift;
     my $parser = Pod::Text->new;
 
+    # Print SOMETHING...
     $parser->output_fh(*STDOUT);
     $parser->parse_file($PROGRAM_NAME);
-    $self->die_usage unless $parser->content_seen;
+    print $self->_usage_message() unless $parser->content_seen;
 
     exit 0;
 }
@@ -980,7 +1015,7 @@ CLI::Startup - Simple initialization for command-line scripts
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =head1 SYNOPSIS
 
@@ -1513,9 +1548,14 @@ any backtrace, by postpending a newline to your message.
 =head2 die_usage
 
   $app->die_usage if $something_wrong;
+  $app->die_usage($message);
 
 Print a help message and exit. This is called internally if the
-user supplies a C<--help> option on the command-line.
+user supplies a C<--help> option on the command-line. If the
+optional C<$message> is specified, then precedes the usage
+message with something like:
+
+  program_name: FATAL: $message
 
 =head2 print_manpage
 
